@@ -90,9 +90,11 @@ class OvmfMemoryRange:
     @staticmethod
     def sev_type(typeid):
         id2name = {
-            1 : "MEM",
-            2 : "Secrets",
-            3 : "CPUID",
+            0x01 : "MEM",
+            0x02 : "Secrets",
+            0x03 : "CPUID",
+            0x04 : "SVSM-CAA",
+            0x10 : "Kernel hashes",
         }
         return id2name.get(typeid, f'{typeid}')
 
