@@ -24,6 +24,7 @@ EfiCustomModeEnable          = "c076ec0c-7028-4399-a072-71ee5c448b9f"
 EfiCertX509                  = "a5c059a1-94e4-4aa7-87b5-ab155c2bf072"
 EfiCertSha256                = "c1c41626-504c-4092-aca9-41f936934328"
 EfiCertPkcs7                 = "4aafd29d-68df-49ee-8aa9-347d375665a7"
+EfiCertExternalMgmt          = "452e8ced-dfff-4b8c-ae01-5118862e682c"
 
 MicrosoftVendor              = "77fa9abd-0359-4d32-bd60-28f4e78f784b"
 OvmfEnrollDefaultKeys        = "a0baa8a3-041d-48a8-bc87-c36d121b5e3d"
@@ -80,6 +81,7 @@ name_table = {
     EfiCertX509                            : "EfiCertX509",
     EfiCertSha256                          : "EfiCertSha256",
     EfiCertPkcs7                           : "EfiCertPkcs7",
+    EfiCertExternalMgmt                    : "EfiCertExternalMgmt",
 
     # signature owner
     MicrosoftVendor                        : "MicrosoftVendor",
@@ -128,3 +130,14 @@ def parse_str(nstr):
         pass
     ustr = from_name(nstr)
     return uuid.UUID(f'urn:uuid:{ustr}')
+
+def parse_auto(data):
+    if data is None:
+        return None
+    if isinstance(data, uuid.UUID):
+        return data
+    if isinstance(data, bytes):
+        return parse_bin(data, 0)
+    if isinstance(data, str):
+        return parse_str(data)
+    raise RuntimeError
